@@ -557,9 +557,26 @@ void Smb4KMounter::import()
   }
 
   // The new list is now the global list.
-  *Smb4KGlobal::mountedSharesList() += shares;
-
-
+  // Loop through the 'shares' list, fix the UNCs and add (copy) each
+  // share to the global list.
+  for ( int i = 0; i < shares.size(); ++i )
+  {
+    Smb4KShare *new_share = new Smb4KShare( *shares[i] );
+    
+    if ( new_share->unc().endsWith( "/" ) )
+    {
+      QString u = new_share->unc();
+      u.chop( 1 );
+      new_share->setUNC( u );
+    }
+    else
+    {
+      // Do nothing
+    }
+    
+    *Smb4KGlobal::mountedSharesList() << new_share;
+  }
+  
   emit updated();
 
   m_working = false;
