@@ -1019,26 +1019,44 @@ const QString Smb4KSambaOptionsHandler::netOptions( NetCommand command, const Sm
       switch ( host.protocol() )
       {
         case Smb4KHost::RPC:
+        {
+          args.append( " "+protocol_hint+" share list -l" );
+          break;
+        }
         case Smb4KHost::RAP:
         {
           // protocol_hint carries the correct protocol:
-          args.append( " "+protocol_hint );
-
+          args.append( " "+protocol_hint+" share -l" );
           break;
         }
         default:
         {
-          if ( QString::compare( default_protocol, "ads", Qt::CaseInsensitive ) != 0 )
+          if ( !default_protocol.isEmpty() )
           {
-            args.append( " "+default_protocol /* can be empty */ );
+            if ( QString::compare( default_protocol, "rpc", Qt::CaseInsensitive ) == 0 )
+            {
+              args.append( " "+default_protocol+" share list -l" );
+            }
+            else if ( QString::compare( default_protocol, "rap", Qt::CaseInsensitive ) == 0 )
+            {
+              args.append( " "+default_protocol+" share -l" );
+            }
+            else
+            {
+              // Automatic detection
+              args.append( " share list -l" );
+            }
           }
-
+          else
+          {
+            // Automatic detection
+            args.append( " share list -l" );
+          }
+          
           break;
         }
       }
 
-      args.append( " share list -l" );
-
       break;
     }
     case LookupHost:
