@@ -48,10 +48,11 @@
 #include <errno.h>
 #include <pwd.h>
 #include <iostream>
-#include <cstdlib>
-
+#include <stdlib.h>
 using namespace std;
 
+#define VERSION "0.4"
+
 
 static const char description[] =
   I18N_NOOP( "This program writes to the sudoers file." );
@@ -517,7 +518,7 @@ int main ( int argc, char *argv[] )
   KAboutData aboutData( "smb4k_sudowriter",
                         "smb4k",
                         ki18n( "smb4k_sudowriter" ),
-                        "0.3",
+                        VERSION,
                         ki18n( description ),
                         KAboutData::License_GPL_V2,
                         ki18n( authors ),
@@ -543,29 +544,6 @@ int main ( int argc, char *argv[] )
   QFile lock_file;
   QFile sudoers;
   
-  switch( createLockFile( &lock_file ) )
-  {
-    case 1:
-    {
-      cerr << argv[0] << ": " << I18N_NOOP( "The lock file could not be created." ) << endl;
-      cerr << argv[0] << ": " << lock_file.errorString().toUtf8().data() << endl;
-      cerr << argv[0] << ": " << I18N_NOOP( "Aborting." ) << endl;
-      exit( EXIT_FAILURE );
-      break;
-    }
-    case 2:
-    {
-      cerr << argv[0] << ": " << I18N_NOOP( "The sudoers file is currently being edited." ) << endl;
-      cerr << argv[0] << ": " << I18N_NOOP( "Aborting." ) << endl;
-      exit( EXIT_FAILURE );
-      break;
-    }
-    default:
-    {
-      break;
-    }
-  }
-  
   // Get the command line arguments.
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
@@ -598,16 +576,36 @@ int main ( int argc, char *argv[] )
     }
   }
   
-  // Throw an error if no argument was provided.
+  // Show usage if no argument was provided.
   if ( adduser.isEmpty() && removeuser.isEmpty() )
   {
-    KCmdLineArgs::usageError( i18n( "No arguments given." ) );
-    removeLockFile( &lock_file );
+    KCmdLineArgs::usageError( i18n( "No valid arguments provided." ) );
     exit( EXIT_FAILURE );
   }
   else
   {
-    // Do nothing
+    switch( createLockFile( &lock_file ) )
+    {
+      case 1:
+      {
+        cerr << argv[0] << ": " << I18N_NOOP( "The lock file could not be created." ) << endl;
+        cerr << argv[0] << ": " << lock_file.errorString().toUtf8().data() << endl;
+        cerr << argv[0] << ": " << I18N_NOOP( "Aborting." ) << endl;
+        exit( EXIT_FAILURE );
+        break;
+      }
+      case 2:
+      {
+        cerr << argv[0] << ": " << I18N_NOOP( "The sudoers file is currently being edited." ) << endl;
+        cerr << argv[0] << ": " << I18N_NOOP( "Aborting." ) << endl;
+        exit( EXIT_FAILURE );
+        break;
+      }
+      default:
+      {
+        break;
+      }
+    }
   }
 
   // Check that the given users are all valid.
